#[repr(C)]pub struct HtOperation {
pub bytes: [u8; 22],
}Fields
bytes: [u8; 22]Trait Implementations
Sourceimpl Clone for HtOperation
impl Clone for HtOperation
Sourcefn clone(&self) -> HtOperation
fn clone(&self) -> HtOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HtOperation
impl Debug for HtOperation
Sourceimpl<'a, ___E> Encode<HtOperation, ___E> for &'a HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<HtOperation, ___E> for &'a HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<HtOperation, ___E> for HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<HtOperation, ___E> for HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
const COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, HtOperation>, ___E> for &'a HtOperation
impl<'a, ___E> EncodeOption<Box<'static, HtOperation>, ___E> for &'a HtOperation
Sourcefn encode_option(
this: Option<&'a HtOperation>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HtOperation>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a HtOperation>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HtOperation>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, HtOperation>, ___E> for HtOperation
impl<___E> EncodeOption<Box<'static, HtOperation>, ___E> for HtOperation
Sourcefn encode_option(
this: Option<HtOperation>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, HtOperation>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<HtOperation>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, HtOperation>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<HtOperation> for HtOperation
impl FromWire<HtOperation> for HtOperation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
const COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
Sourcefn from_wire(wire: HtOperation) -> HtOperation
fn from_wire(wire: HtOperation) -> HtOperation
Converts the given owned value to this type.
Sourceimpl FromWireRef<HtOperation> for HtOperation
impl FromWireRef<HtOperation> for HtOperation
Sourcefn from_wire_ref(wire: &HtOperation) -> HtOperation
fn from_wire_ref(wire: &HtOperation) -> HtOperation
Converts the given reference to this type.
Sourceimpl Hash for HtOperation
impl Hash for HtOperation
Sourceimpl Ord for HtOperation
impl Ord for HtOperation
Sourcefn cmp(&self, other: &HtOperation) -> Ordering
fn cmp(&self, other: &HtOperation) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HtOperation
impl PartialEq for HtOperation
Sourcefn eq(&self, other: &HtOperation) -> bool
fn eq(&self, other: &HtOperation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HtOperation
impl PartialOrd for HtOperation
impl Copy for HtOperation
impl Eq for HtOperation
impl StructuralPartialEq for HtOperation