#[repr(C)]pub struct VhtOperation {
pub bytes: [u8; 5],
}Fields
bytes: [u8; 5]Trait Implementations
Sourceimpl Clone for VhtOperation
impl Clone for VhtOperation
Sourcefn clone(&self) -> VhtOperation
fn clone(&self) -> VhtOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VhtOperation
impl Debug for VhtOperation
Sourceimpl<'a, ___E> Encode<VhtOperation, ___E> for &'a VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<VhtOperation, ___E> for &'a VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VhtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VhtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<VhtOperation, ___E> for VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<VhtOperation, ___E> for VhtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<VhtOperation, VhtOperation>
const COPY_OPTIMIZATION: CopyOptimization<VhtOperation, VhtOperation>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VhtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VhtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, VhtOperation>, ___E> for &'a VhtOperation
impl<'a, ___E> EncodeOption<Box<'static, VhtOperation>, ___E> for &'a VhtOperation
Sourcefn encode_option(
this: Option<&'a VhtOperation>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VhtOperation>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a VhtOperation>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VhtOperation>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, VhtOperation>, ___E> for VhtOperation
impl<___E> EncodeOption<Box<'static, VhtOperation>, ___E> for VhtOperation
Sourcefn encode_option(
this: Option<VhtOperation>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VhtOperation>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<VhtOperation>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VhtOperation>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<VhtOperation> for VhtOperation
impl FromWire<VhtOperation> for VhtOperation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<VhtOperation, VhtOperation>
const COPY_OPTIMIZATION: CopyOptimization<VhtOperation, VhtOperation>
Sourcefn from_wire(wire: VhtOperation) -> VhtOperation
fn from_wire(wire: VhtOperation) -> VhtOperation
Converts the given owned value to this type.
Sourceimpl FromWireRef<VhtOperation> for VhtOperation
impl FromWireRef<VhtOperation> for VhtOperation
Sourcefn from_wire_ref(wire: &VhtOperation) -> VhtOperation
fn from_wire_ref(wire: &VhtOperation) -> VhtOperation
Converts the given reference to this type.
Sourceimpl Hash for VhtOperation
impl Hash for VhtOperation
Sourceimpl Ord for VhtOperation
impl Ord for VhtOperation
Sourcefn cmp(&self, other: &VhtOperation) -> Ordering
fn cmp(&self, other: &VhtOperation) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VhtOperation
impl PartialEq for VhtOperation
Sourcefn eq(&self, other: &VhtOperation) -> bool
fn eq(&self, other: &VhtOperation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VhtOperation
impl PartialOrd for VhtOperation
impl Copy for VhtOperation
impl Eq for VhtOperation
impl StructuralPartialEq for VhtOperation