#[repr(C)]pub struct HtOperation {
pub bytes: [u8; 22],
}Expand description
The wire type corresponding to HtOperation.
Fields
bytes: [u8; 22]Trait Implementations
Sourceimpl Clone for HtOperation
impl Clone for HtOperation
Sourcefn clone(&self) -> HtOperation
fn clone(&self) -> HtOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for HtOperation
impl Constrained for HtOperation
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, HtOperation>,
_: <HtOperation as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, HtOperation>, _: <HtOperation as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for HtOperation
impl Debug for HtOperation
Sourceimpl<___D> Decode<___D> for HtOperationwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for HtOperationwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<HtOperation, ___E> for &'a HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<HtOperation, ___E> for &'a HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<HtOperation, ___E> for HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<HtOperation, ___E> for HtOperationwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
const COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<HtOperation, ___E> for HtOperation<T0>
impl<___E, T0> Encode<HtOperation, ___E> for HtOperation<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<HtOperation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<HtOperation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<HtOperation> for HtOperation
impl FromWire<HtOperation> for HtOperation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
const COPY_OPTIMIZATION: CopyOptimization<HtOperation, HtOperation>
Sourcefn from_wire(wire: HtOperation) -> HtOperation
fn from_wire(wire: HtOperation) -> HtOperation
Converts the given owned value to this type.
Sourceimpl FromWireRef<HtOperation> for HtOperation
impl FromWireRef<HtOperation> for HtOperation
Sourcefn from_wire_ref(wire: &HtOperation) -> HtOperation
fn from_wire_ref(wire: &HtOperation) -> HtOperation
Converts the given reference to this type.
Sourceimpl IntoNatural for HtOperation
impl IntoNatural for HtOperation
Sourcetype Natural = HtOperation
type Natural = HtOperation
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for HtOperation
impl Wire for HtOperation
Sourcetype Narrowed<'de> = HtOperation
type Narrowed<'de> = HtOperation
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<HtOperation>)
fn zero_padding(out_: &mut MaybeUninit<HtOperation>)
Writes zeroes to the padding for this type, if any.